# Changelog

## 0.1.0-alpha.1 (2024-08-02)

Full Changelog: [v0.0.1-alpha.1...v0.1.0-alpha.1](https://github.com/EndexAI/factset-events-and-transcripts-api-python/compare/v0.0.1-alpha.1...v0.1.0-alpha.1)

### Features

* **api:** update via SDK Studio ([#5](https://github.com/EndexAI/factset-events-and-transcripts-api-python/issues/5)) ([28fe53f](https://github.com/EndexAI/factset-events-and-transcripts-api-python/commit/28fe53f102e941255deb592abe2cc3be3d99afda))
* **api:** update via SDK Studio ([#7](https://github.com/EndexAI/factset-events-and-transcripts-api-python/issues/7)) ([3a49bb0](https://github.com/EndexAI/factset-events-and-transcripts-api-python/commit/3a49bb0bd36dcf1374850a61ae6052da725da105))
* **api:** update via SDK Studio ([#8](https://github.com/EndexAI/factset-events-and-transcripts-api-python/issues/8)) ([28a8e63](https://github.com/EndexAI/factset-events-and-transcripts-api-python/commit/28a8e6323b5e6ead0126d74f4a2ad5e9f4113a77))
* **api:** update via SDK Studio ([#9](https://github.com/EndexAI/factset-events-and-transcripts-api-python/issues/9)) ([a30f808](https://github.com/EndexAI/factset-events-and-transcripts-api-python/commit/a30f808930948b1aa31572cf0c83f988f0a13064))

## 0.0.1-alpha.1 (2024-08-02)

Full Changelog: [v0.0.1-alpha.0...v0.0.1-alpha.1](https://github.com/EndexAI/factset-events-and-transcripts-api-python/compare/v0.0.1-alpha.0...v0.0.1-alpha.1)

### Chores

* configure new SDK language ([7f12382](https://github.com/EndexAI/factset-events-and-transcripts-api-python/commit/7f12382e93781864a8a2feeac71279bb0df733a1))
* go live ([#1](https://github.com/EndexAI/factset-events-and-transcripts-api-python/issues/1)) ([6caa15e](https://github.com/EndexAI/factset-events-and-transcripts-api-python/commit/6caa15edd26431d0a49f25e73fdec475cc98da18))
